package soccerTeamExample_textbookVersion;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JPanel;
import javax.swing.JTextField;

public class TeamMemberView extends JPanel implements TeamMemberModelListener,
		ActionListener {
	private TeamMemberModel theModel;

	private LabeledTextComponent firstNameComponent;
	private LabeledTextComponent lastNameComponent;
	private LabeledTextComponent addressComponent;
	private LabeledTextComponent phoneNumberComponent;
	private JTextField theMessage;
	private final String MSG_PREFIX = "Summary: ";

	private boolean isActive = false;

	public TeamMemberView(TeamMemberModel model) {
		theModel = model;
		model.addTeamMemberListener(this);
		
		firstNameComponent = new LabeledTextComponent("First Name:");
		lastNameComponent = new LabeledTextComponent("Last Name:");
		addressComponent = new LabeledTextComponent("Address:");
		phoneNumberComponent = new LabeledTextComponent("Phone Number:");

		theMessage = new JTextField(MSG_PREFIX, 30);
		theMessage.setEditable(false);

		/**
		 * ref p.99 At this point, the JPanel does not have knowledge about the
		 * widgets that have been constructed above. The above widgets are not
		 * added into the widget tree (see p. 17, fig 2.3) unless the add
		 * operation has been specifically invoked. Recall that membership in
		 * the window's widget tree allows the widget to be drawn and to receive
		 * events.
		 * 
		 * So we add each of the widgets to this panel's widget tree
		 */
		this.add(firstNameComponent);
		this.add(lastNameComponent);
		this.add(addressComponent);
		this.add(phoneNumberComponent);
		this.add(theMessage);

		/**
		 * pp. 101-102. The widgets will generate events that are produced when
		 * the user types new text into the text boxed. We want the controller
		 * to be aware of such events so that it can update the model
		 * accordingly.
		 * 
		 */
		firstNameComponent.addActionListener(this);
		lastNameComponent.addActionListener(this);
		addressComponent.addActionListener(this);
		phoneNumberComponent.addActionListener(this);
	}

	public Dimension getPreferredSize() {
		return new Dimension(400, 300);
	}

	public LabeledTextComponent getFirstNameComponent() {
		return firstNameComponent;
	}

	public LabeledTextComponent getLastNameComponent() {
		return lastNameComponent;
	}

	public LabeledTextComponent getAddressComponent() {
		return addressComponent;
	}

	public LabeledTextComponent getPhoneNumberComponent() {
		return phoneNumberComponent;
	}

	public void setSummaryMessage(String theNewMessage) {
		this.theMessage.setText(MSG_PREFIX + theNewMessage);
	}

	@Override
	public void changed() {
//		firstNameComponent.setText(theModel.getFirstName());
//		lastNameComponent.setText(theModel.getLastName());
//		addressComponent.setText(theModel.getAddress());
//		phoneNumberComponent.setText(theModel.getPhoneNumber());
		this.setSummaryMessage(theModel.toString());
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		if (isActive)
			return;
		isActive = true;
		theModel.setFirstName(getFirstNameComponent().getText());
		theModel.setLastName(getLastNameComponent().getText());
		theModel.setAddress(getAddressComponent().getText());
		theModel.setPhoneNumber(getPhoneNumberComponent().getText());
		isActive = false;
	}

}
